@@ -1,4 +1,5 @@
 """Plot regression figure."""
+
 import warnings
 from numbers import Integral
 from itertools import repeat
@@ -299,20 +300,47 @@ def plot_lm(
     # Filter out the required values to generate plotters
     if y_model is not None:
         if kind_model == "lines":
-            y_model = y_model.stack(__sample__=("chain", "draw"))[..., pp_sample_ix]
+            var_name = y_model.name if y_model.name else "y_model"
+            data = y_model.values
 
-        y_model = [
-            tup
-            for _, tup in zip(
-                range(len_y),
-                xarray_var_iter(
-                    y_model,
-                    skip_dims=set(y_model.dims),
-                    combined=True,
-                ),
-            )
-        ]
-        y_model = _repeat_flatten_list(y_model, len_x)
+            total_samples = data.shape[0] * data.shape[1]
+            data = data.reshape(total_samples, *data.shape[2:])
+
+            if pp_sample_ix is not None:
+                data = data[pp_sample_ix]
+
+            if plot_dim is not None:
+                # For plot_dim case, transpose to get dimension first
+                data = data.transpose(1, 0, 2)[..., 0]
+
+            # Create plotter tuple(s)
+            if plot_dim is not None:
+                y_model = [(var_name, {}, {}, data) for _ in range(length_plotters)]
+            else:
+                y_model = [(var_name, {}, {}, data)]
+                y_model = _repeat_flatten_list(y_model, len_x)
+
+        elif kind_model == "hdi":
+            var_name = y_model.name if y_model.name else "y_model"
+            data = y_model.values
+
+            if plot_dim is not None:
+                # First transpose to get plot_dim first
+                data = data.transpose(2, 0, 1, 3)
+                # For plot_dim case, we just want HDI for first dimension
+                data = data[..., 0]
+
+                # Reshape to (samples, points)
+                data = data.transpose(1, 2, 0).reshape(-1, data.shape[0])
+                y_model = [(var_name, {}, {}, data) for _ in range(length_plotters)]
+
+            else:
+                data = data.reshape(-1, data.shape[-1])
+                y_model = [(var_name, {}, {}, data)]
+                y_model = _repeat_flatten_list(y_model, len_x)
+
+        if len(y_model) == 1:
+            y_model = _repeat_flatten_list(y_model, len_x)
 
     rows, cols = default_grid(length_plotters)
 
